@@ -23,6 +23,10 @@ class Connector(object):
 
         self.connector.disconnect()
 
+    def create_new_connection(self):
+
+        return Connector(self.ip, self.port)
+
     def query(self, q, blobs=[], n_retries=0):
 
         if n_retries == 0:
@@ -47,8 +51,12 @@ class Connector(object):
                 error_msg  = "Warning: Query failed after " + str(n_retries)
                 error_msg += " retries\n"
                 sys.stderr.write(error_msg)
+                sys.stderr.write("Response: \n")
                 sys.stderr.write(self.connector.get_last_response_str())
                 sys.stderr.write("\n")
+                sys.stderr.write("Query: \n")
+                sys.stderr.write(str(q))
+                sys.stderr.write("\n")
                 break
 
             start = time.time()
